Class: ProcessOut::Discount
- Inherits:
-
Object
- Object
- ProcessOut::Discount
- Defined in:
- lib/processout/discount.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Returns the value of attribute amount.
-
#coupon ⇒ Object
Returns the value of attribute coupon.
-
#coupon_id ⇒ Object
Returns the value of attribute coupon_id.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#expires_at ⇒ Object
Returns the value of attribute expires_at.
-
#id ⇒ Object
Returns the value of attribute id.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#name ⇒ Object
Returns the value of attribute name.
-
#percent ⇒ Object
Returns the value of attribute percent.
-
#project ⇒ Object
Returns the value of attribute project.
-
#project_id ⇒ Object
Returns the value of attribute project_id.
-
#sandbox ⇒ Object
Returns the value of attribute sandbox.
-
#subscription ⇒ Object
Returns the value of attribute subscription.
-
#subscription_id ⇒ Object
Returns the value of attribute subscription_id.
Instance Method Summary collapse
-
#apply(subscription_id, options = {}) ⇒ Object
Apply a new discount to the given subscription ID.
-
#fill_with_data(data) ⇒ Object
- Fills the object with data coming from the API Params:
data -
Hashof data coming from the API.
- Fills the object with data coming from the API Params:
-
#find(subscription_id, discount_id, options = {}) ⇒ Object
Find a subscription’s discount by its ID.
-
#initialize(client, data = {}) ⇒ Discount
constructor
- Initializes the Discount object Params:
client ProcessOutclient instancedata-
data that can be used to fill the object.
- Initializes the Discount object Params:
-
#new(data = {}) ⇒ Object
Create a new Discount using the current client.
-
#prefill(data) ⇒ Object
- Prefills the object with the data passed as parameters Params:
data -
Hashof data.
- Prefills the object with the data passed as parameters Params:
-
#remove(subscription_id, discount_id, options = {}) ⇒ Object
Remove a discount applied to a subscription.
Constructor Details
#initialize(client, data = {}) ⇒ Discount
Initializes the Discount object Params:
client-
ProcessOutclient instance data-
data that can be used to fill the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/processout/discount.rb', line 123 def initialize(client, data = {}) @client = client self.id = data.fetch(:id, nil) self.project = data.fetch(:project, nil) self.project_id = data.fetch(:project_id, nil) self.subscription = data.fetch(:subscription, nil) self.subscription_id = data.fetch(:subscription_id, nil) self.coupon = data.fetch(:coupon, nil) self.coupon_id = data.fetch(:coupon_id, nil) self.name = data.fetch(:name, nil) self.amount = data.fetch(:amount, nil) self.percent = data.fetch(:percent, nil) self.expires_at = data.fetch(:expires_at, nil) self. = data.fetch(:metadata, nil) self.sandbox = data.fetch(:sandbox, nil) self.created_at = data.fetch(:created_at, nil) end |
Instance Attribute Details
#amount ⇒ Object
Returns the value of attribute amount.
18 19 20 |
# File 'lib/processout/discount.rb', line 18 def amount @amount end |
#coupon ⇒ Object
Returns the value of attribute coupon.
15 16 17 |
# File 'lib/processout/discount.rb', line 15 def coupon @coupon end |
#coupon_id ⇒ Object
Returns the value of attribute coupon_id.
16 17 18 |
# File 'lib/processout/discount.rb', line 16 def coupon_id @coupon_id end |
#created_at ⇒ Object
Returns the value of attribute created_at.
23 24 25 |
# File 'lib/processout/discount.rb', line 23 def created_at @created_at end |
#expires_at ⇒ Object
Returns the value of attribute expires_at.
20 21 22 |
# File 'lib/processout/discount.rb', line 20 def expires_at @expires_at end |
#id ⇒ Object
Returns the value of attribute id.
10 11 12 |
# File 'lib/processout/discount.rb', line 10 def id @id end |
#metadata ⇒ Object
Returns the value of attribute metadata.
21 22 23 |
# File 'lib/processout/discount.rb', line 21 def @metadata end |
#name ⇒ Object
Returns the value of attribute name.
17 18 19 |
# File 'lib/processout/discount.rb', line 17 def name @name end |
#percent ⇒ Object
Returns the value of attribute percent.
19 20 21 |
# File 'lib/processout/discount.rb', line 19 def percent @percent end |
#project ⇒ Object
Returns the value of attribute project.
11 12 13 |
# File 'lib/processout/discount.rb', line 11 def project @project end |
#project_id ⇒ Object
Returns the value of attribute project_id.
12 13 14 |
# File 'lib/processout/discount.rb', line 12 def project_id @project_id end |
#sandbox ⇒ Object
Returns the value of attribute sandbox.
22 23 24 |
# File 'lib/processout/discount.rb', line 22 def sandbox @sandbox end |
#subscription ⇒ Object
Returns the value of attribute subscription.
13 14 15 |
# File 'lib/processout/discount.rb', line 13 def subscription @subscription end |
#subscription_id ⇒ Object
Returns the value of attribute subscription_id.
14 15 16 |
# File 'lib/processout/discount.rb', line 14 def subscription_id @subscription_id end |
Instance Method Details
#apply(subscription_id, options = {}) ⇒ Object
Apply a new discount to the given subscription ID. Params:
subscription_id-
ID of the subscription
options-
Hashof options
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/processout/discount.rb', line 230 def apply(subscription_id, = {}) self.prefill() request = Request.new(@client) path = "/subscriptions/" + CGI.escape(subscription_id) + "/discounts" data = { "coupon_id" => @coupon_id, "name" => @name, "amount" => @amount, "expires_at" => @expires_at, "metadata" => @metadata } response = Response.new(request.post(path, data, )) return_values = Array.new body = response.body body = body["discount"] return_values.push(self.fill_with_data(body)) return_values[0] end |
#fill_with_data(data) ⇒ Object
Fills the object with data coming from the API Params:
data-
Hashof data coming from the API
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/processout/discount.rb', line 151 def fill_with_data(data) if data.nil? return self end if data.include? "id" self.id = data["id"] end if data.include? "project" self.project = data["project"] end if data.include? "project_id" self.project_id = data["project_id"] end if data.include? "subscription" self.subscription = data["subscription"] end if data.include? "subscription_id" self.subscription_id = data["subscription_id"] end if data.include? "coupon" self.coupon = data["coupon"] end if data.include? "coupon_id" self.coupon_id = data["coupon_id"] end if data.include? "name" self.name = data["name"] end if data.include? "amount" self.amount = data["amount"] end if data.include? "percent" self.percent = data["percent"] end if data.include? "expires_at" self.expires_at = data["expires_at"] end if data.include? "metadata" self. = data["metadata"] end if data.include? "sandbox" self.sandbox = data["sandbox"] end if data.include? "created_at" self.created_at = data["created_at"] end self end |
#find(subscription_id, discount_id, options = {}) ⇒ Object
Find a subscription’s discount by its ID. Params:
subscription_id-
ID of the subscription on which the discount was applied
discount_id-
ID of the discount
options-
Hashof options
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/processout/discount.rb', line 262 def find(subscription_id, discount_id, = {}) self.prefill() request = Request.new(@client) path = "/subscriptions/" + CGI.escape(subscription_id) + "/discounts/" + CGI.escape(discount_id) + "" data = { } response = Response.new(request.get(path, data, )) return_values = Array.new body = response.body body = body["discount"] obj = Discount.new(@client) return_values.push(obj.fill_with_data(body)) return_values[0] end |
#new(data = {}) ⇒ Object
Create a new Discount using the current client
144 145 146 |
# File 'lib/processout/discount.rb', line 144 def new(data = {}) Discount.new(@client, data) end |
#prefill(data) ⇒ Object
Prefills the object with the data passed as parameters Params:
data-
Hashof data
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/processout/discount.rb', line 204 def prefill(data) if data.nil? return self end self.id = data.fetch(:id, self.id) self.project = data.fetch(:project, self.project) self.project_id = data.fetch(:project_id, self.project_id) self.subscription = data.fetch(:subscription, self.subscription) self.subscription_id = data.fetch(:subscription_id, self.subscription_id) self.coupon = data.fetch(:coupon, self.coupon) self.coupon_id = data.fetch(:coupon_id, self.coupon_id) self.name = data.fetch(:name, self.name) self.amount = data.fetch(:amount, self.amount) self.percent = data.fetch(:percent, self.percent) self.expires_at = data.fetch(:expires_at, self.expires_at) self. = data.fetch(:metadata, self.) self.sandbox = data.fetch(:sandbox, self.sandbox) self.created_at = data.fetch(:created_at, self.created_at) self end |
#remove(subscription_id, discount_id, options = {}) ⇒ Object
Remove a discount applied to a subscription. Params:
subscription_id-
ID of the subscription on which the discount was applied
discount_id-
ID of the discount
options-
Hashof options
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/processout/discount.rb', line 291 def remove(subscription_id, discount_id, = {}) self.prefill() request = Request.new(@client) path = "/subscriptions/" + CGI.escape(subscription_id) + "/discounts/" + CGI.escape(discount_id) + "" data = { } response = Response.new(request.delete(path, data, )) return_values = Array.new return_values.push(response.success) return_values[0] end |