Class: ProcessOut::Invoice
- Inherits:
-
Object
- Object
- ProcessOut::Invoice
- Defined in:
- lib/processout/invoice.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Returns the value of attribute amount.
-
#auto_capture_at ⇒ Object
Returns the value of attribute auto_capture_at.
-
#billing ⇒ Object
Returns the value of attribute billing.
-
#cancel_url ⇒ Object
Returns the value of attribute cancel_url.
-
#challenge_indicator ⇒ Object
Returns the value of attribute challenge_indicator.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#customer ⇒ Object
Returns the value of attribute customer.
-
#customer_id ⇒ Object
Returns the value of attribute customer_id.
-
#details ⇒ Object
Returns the value of attribute details.
-
#device ⇒ Object
Returns the value of attribute device.
-
#exemption_reason_3ds2 ⇒ Object
Returns the value of attribute exemption_reason_3ds2.
-
#expires_at ⇒ Object
Returns the value of attribute expires_at.
-
#external_fraud_tools ⇒ Object
Returns the value of attribute external_fraud_tools.
-
#gateway_data ⇒ Object
Returns the value of attribute gateway_data.
-
#id ⇒ Object
Returns the value of attribute id.
-
#incremental ⇒ Object
Returns the value of attribute incremental.
-
#initiation_type ⇒ Object
Returns the value of attribute initiation_type.
-
#merchant_initiator_type ⇒ Object
Returns the value of attribute merchant_initiator_type.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#name ⇒ Object
Returns the value of attribute name.
-
#native_apm ⇒ Object
Returns the value of attribute native_apm.
-
#order_id ⇒ Object
Returns the value of attribute order_id.
-
#payment_intent ⇒ Object
Returns the value of attribute payment_intent.
-
#payment_processing_config ⇒ Object
Returns the value of attribute payment_processing_config.
-
#payment_type ⇒ Object
Returns the value of attribute payment_type.
-
#project ⇒ Object
Returns the value of attribute project.
-
#project_id ⇒ Object
Returns the value of attribute project_id.
-
#reference_id ⇒ Object
Returns the value of attribute reference_id.
-
#require_backend_capture ⇒ Object
Returns the value of attribute require_backend_capture.
-
#return_url ⇒ Object
Returns the value of attribute return_url.
-
#risk ⇒ Object
Returns the value of attribute risk.
-
#sandbox ⇒ Object
Returns the value of attribute sandbox.
-
#sca_exemption_reason ⇒ Object
Returns the value of attribute sca_exemption_reason.
-
#shipping ⇒ Object
Returns the value of attribute shipping.
-
#statement_descriptor ⇒ Object
Returns the value of attribute statement_descriptor.
-
#statement_descriptor_city ⇒ Object
Returns the value of attribute statement_descriptor_city.
-
#statement_descriptor_company ⇒ Object
Returns the value of attribute statement_descriptor_company.
-
#statement_descriptor_phone ⇒ Object
Returns the value of attribute statement_descriptor_phone.
-
#statement_descriptor_url ⇒ Object
Returns the value of attribute statement_descriptor_url.
-
#submerchant ⇒ Object
Returns the value of attribute submerchant.
-
#submerchant_id ⇒ Object
Returns the value of attribute submerchant_id.
-
#tax ⇒ Object
Returns the value of attribute tax.
-
#token ⇒ Object
Returns the value of attribute token.
-
#token_id ⇒ Object
Returns the value of attribute token_id.
-
#transaction ⇒ Object
Returns the value of attribute transaction.
-
#transaction_id ⇒ Object
Returns the value of attribute transaction_id.
-
#unsupported_feature_bypass ⇒ Object
Returns the value of attribute unsupported_feature_bypass.
-
#url ⇒ Object
Returns the value of attribute url.
-
#url_qrcode ⇒ Object
Returns the value of attribute url_qrcode.
-
#verification ⇒ Object
Returns the value of attribute verification.
-
#webhook_url ⇒ Object
Returns the value of attribute webhook_url.
Instance Method Summary collapse
-
#all(options = {}) ⇒ Object
Get all the invoices.
-
#assign_customer(customer_id, options = {}) ⇒ Object
Assign a customer to the invoice.
-
#authenticate(source, options = {}) ⇒ Object
Autheticate the invoice using the given source (customer or token) Params:
source:: Source used to authenticate the payment. -
#authorize(source, options = {}) ⇒ Object
Authorize the invoice using the given source (customer or token) Params:
source:: Source used to authorization the payment. -
#capture(source, options = {}) ⇒ Object
Capture the invoice using the given source (customer or token) Params:
source:: Source used to authorization the payment. -
#create(options = {}) ⇒ Object
Create a new invoice.
-
#delete(invoice_id, options = {}) ⇒ Object
Delete an invoice by its ID.
-
#fetch_customer(options = {}) ⇒ Object
Get the customer linked to the invoice.
-
#fetch_transaction(options = {}) ⇒ Object
Get the transaction of the invoice.
-
#fill_with_data(data) ⇒ Object
Fills the object with data coming from the API Params:
data::Hashof data coming from the API. -
#find(invoice_id, options = {}) ⇒ Object
Find an invoice by its ID.
-
#increment_authorization(amount, options = {}) ⇒ Object
Create an incremental authorization Params:
amount:: Amount to increment authorization byoptions::Hashof options. -
#initialize(client, data = {}) ⇒ Invoice
constructor
Initializes the Invoice object Params:
client::ProcessOutclient instancedata:: data that can be used to fill the object. -
#initiate_three_d_s(source, options = {}) ⇒ Object
Initiate a 3-D Secure authentication Params:
source:: Source used to initiate the 3-D Secure authentication. -
#new(data = {}) ⇒ Object
Create a new Invoice using the current client.
-
#payout(gateway_configuration_id, source, options = {}) ⇒ Object
Process the payout invoice using the given source (customer or token) Params:
gateway_configuration_id:: ID of the configuration, that processes payoutsource:: Source used to process the payout. -
#prefill(data) ⇒ Object
Prefills the object with the data passed as parameters Params:
data::Hashof data. -
#process_native_payment(invoice_id, options = {}) ⇒ Object
Process the Native APM payment flow Params:
invoice_id:: ID of the invoiceoptions::Hashof options. -
#show_native_payment_transaction(invoice_id, gateway_configuration_id, options = {}) ⇒ Object
Fetches the Native APM payment Params:
invoice_id:: ID of the invoicegateway_configuration_id:: ID of the native APM configurationoptions::Hashof options. -
#sync_with_psp(invoice_id, options = {}) ⇒ Object
Refresh invoice by its ID with PSP.
-
#to_json(options) ⇒ Object
Overrides the JSON marshaller to only send the fields we want.
-
#update(invoice_id, options = {}) ⇒ Object
Update invoice by its ID.
-
#void(options = {}) ⇒ Object
Void the invoice Params:
options::Hashof options.
Constructor Details
#initialize(client, data = {}) ⇒ Invoice
Initializes the Invoice object Params:
clientProcessOutclient instancedatadata that can be used to fill the object
462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/processout/invoice.rb', line 462 def initialize(client, data = {}) @client = client self.id = data.fetch(:id, nil) self.project = data.fetch(:project, nil) self.project_id = data.fetch(:project_id, nil) self.transaction = data.fetch(:transaction, nil) self.transaction_id = data.fetch(:transaction_id, nil) self.customer = data.fetch(:customer, nil) self.customer_id = data.fetch(:customer_id, nil) self.token = data.fetch(:token, nil) self.token_id = data.fetch(:token_id, nil) self.details = data.fetch(:details, nil) self.submerchant = data.fetch(:submerchant, nil) self.submerchant_id = data.fetch(:submerchant_id, nil) self.url = data.fetch(:url, nil) self.url_qrcode = data.fetch(:url_qrcode, nil) self.name = data.fetch(:name, nil) self.order_id = data.fetch(:order_id, nil) self.amount = data.fetch(:amount, nil) self.currency = data.fetch(:currency, nil) self.merchant_initiator_type = data.fetch(:merchant_initiator_type, nil) self.statement_descriptor = data.fetch(:statement_descriptor, nil) self.statement_descriptor_phone = data.fetch(:statement_descriptor_phone, nil) self.statement_descriptor_city = data.fetch(:statement_descriptor_city, nil) self.statement_descriptor_company = data.fetch(:statement_descriptor_company, nil) self.statement_descriptor_url = data.fetch(:statement_descriptor_url, nil) self. = data.fetch(:metadata, nil) self.gateway_data = data.fetch(:gateway_data, nil) self.return_url = data.fetch(:return_url, nil) self.cancel_url = data.fetch(:cancel_url, nil) self.webhook_url = data.fetch(:webhook_url, nil) self.require_backend_capture = data.fetch(:require_backend_capture, nil) self.sandbox = data.fetch(:sandbox, nil) self.created_at = data.fetch(:created_at, nil) self.expires_at = data.fetch(:expires_at, nil) self.risk = data.fetch(:risk, nil) self.shipping = data.fetch(:shipping, nil) self.device = data.fetch(:device, nil) self.external_fraud_tools = data.fetch(:external_fraud_tools, nil) self.exemption_reason_3ds2 = data.fetch(:exemption_reason_3ds2, nil) self.sca_exemption_reason = data.fetch(:sca_exemption_reason, nil) self.challenge_indicator = data.fetch(:challenge_indicator, nil) self.incremental = data.fetch(:incremental, nil) self.tax = data.fetch(:tax, nil) self.payment_type = data.fetch(:payment_type, nil) self.native_apm = data.fetch(:native_apm, nil) self.initiation_type = data.fetch(:initiation_type, nil) self.payment_intent = data.fetch(:payment_intent, nil) self.billing = data.fetch(:billing, nil) self.unsupported_feature_bypass = data.fetch(:unsupported_feature_bypass, nil) self.verification = data.fetch(:verification, nil) self.auto_capture_at = data.fetch(:auto_capture_at, nil) self.reference_id = data.fetch(:reference_id, nil) self.payment_processing_config = data.fetch(:payment_processing_config, nil) end |
Instance Attribute Details
#amount ⇒ Object
Returns the value of attribute amount.
27 28 29 |
# File 'lib/processout/invoice.rb', line 27 def amount @amount end |
#auto_capture_at ⇒ Object
Returns the value of attribute auto_capture_at.
60 61 62 |
# File 'lib/processout/invoice.rb', line 60 def auto_capture_at @auto_capture_at end |
#billing ⇒ Object
Returns the value of attribute billing.
57 58 59 |
# File 'lib/processout/invoice.rb', line 57 def billing @billing end |
#cancel_url ⇒ Object
Returns the value of attribute cancel_url.
38 39 40 |
# File 'lib/processout/invoice.rb', line 38 def cancel_url @cancel_url end |
#challenge_indicator ⇒ Object
Returns the value of attribute challenge_indicator.
50 51 52 |
# File 'lib/processout/invoice.rb', line 50 def challenge_indicator @challenge_indicator end |
#created_at ⇒ Object
Returns the value of attribute created_at.
42 43 44 |
# File 'lib/processout/invoice.rb', line 42 def created_at @created_at end |
#currency ⇒ Object
Returns the value of attribute currency.
28 29 30 |
# File 'lib/processout/invoice.rb', line 28 def currency @currency end |
#customer ⇒ Object
Returns the value of attribute customer.
16 17 18 |
# File 'lib/processout/invoice.rb', line 16 def customer @customer end |
#customer_id ⇒ Object
Returns the value of attribute customer_id.
17 18 19 |
# File 'lib/processout/invoice.rb', line 17 def customer_id @customer_id end |
#details ⇒ Object
Returns the value of attribute details.
20 21 22 |
# File 'lib/processout/invoice.rb', line 20 def details @details end |
#device ⇒ Object
Returns the value of attribute device.
46 47 48 |
# File 'lib/processout/invoice.rb', line 46 def device @device end |
#exemption_reason_3ds2 ⇒ Object
Returns the value of attribute exemption_reason_3ds2.
48 49 50 |
# File 'lib/processout/invoice.rb', line 48 def exemption_reason_3ds2 @exemption_reason_3ds2 end |
#expires_at ⇒ Object
Returns the value of attribute expires_at.
43 44 45 |
# File 'lib/processout/invoice.rb', line 43 def expires_at @expires_at end |
#external_fraud_tools ⇒ Object
Returns the value of attribute external_fraud_tools.
47 48 49 |
# File 'lib/processout/invoice.rb', line 47 def external_fraud_tools @external_fraud_tools end |
#gateway_data ⇒ Object
Returns the value of attribute gateway_data.
36 37 38 |
# File 'lib/processout/invoice.rb', line 36 def gateway_data @gateway_data end |
#id ⇒ Object
Returns the value of attribute id.
11 12 13 |
# File 'lib/processout/invoice.rb', line 11 def id @id end |
#incremental ⇒ Object
Returns the value of attribute incremental.
51 52 53 |
# File 'lib/processout/invoice.rb', line 51 def incremental @incremental end |
#initiation_type ⇒ Object
Returns the value of attribute initiation_type.
55 56 57 |
# File 'lib/processout/invoice.rb', line 55 def initiation_type @initiation_type end |
#merchant_initiator_type ⇒ Object
Returns the value of attribute merchant_initiator_type.
29 30 31 |
# File 'lib/processout/invoice.rb', line 29 def merchant_initiator_type @merchant_initiator_type end |
#metadata ⇒ Object
Returns the value of attribute metadata.
35 36 37 |
# File 'lib/processout/invoice.rb', line 35 def @metadata end |
#name ⇒ Object
Returns the value of attribute name.
25 26 27 |
# File 'lib/processout/invoice.rb', line 25 def name @name end |
#native_apm ⇒ Object
Returns the value of attribute native_apm.
54 55 56 |
# File 'lib/processout/invoice.rb', line 54 def native_apm @native_apm end |
#order_id ⇒ Object
Returns the value of attribute order_id.
26 27 28 |
# File 'lib/processout/invoice.rb', line 26 def order_id @order_id end |
#payment_intent ⇒ Object
Returns the value of attribute payment_intent.
56 57 58 |
# File 'lib/processout/invoice.rb', line 56 def payment_intent @payment_intent end |
#payment_processing_config ⇒ Object
Returns the value of attribute payment_processing_config.
62 63 64 |
# File 'lib/processout/invoice.rb', line 62 def payment_processing_config @payment_processing_config end |
#payment_type ⇒ Object
Returns the value of attribute payment_type.
53 54 55 |
# File 'lib/processout/invoice.rb', line 53 def payment_type @payment_type end |
#project ⇒ Object
Returns the value of attribute project.
12 13 14 |
# File 'lib/processout/invoice.rb', line 12 def project @project end |
#project_id ⇒ Object
Returns the value of attribute project_id.
13 14 15 |
# File 'lib/processout/invoice.rb', line 13 def project_id @project_id end |
#reference_id ⇒ Object
Returns the value of attribute reference_id.
61 62 63 |
# File 'lib/processout/invoice.rb', line 61 def reference_id @reference_id end |
#require_backend_capture ⇒ Object
Returns the value of attribute require_backend_capture.
40 41 42 |
# File 'lib/processout/invoice.rb', line 40 def require_backend_capture @require_backend_capture end |
#return_url ⇒ Object
Returns the value of attribute return_url.
37 38 39 |
# File 'lib/processout/invoice.rb', line 37 def return_url @return_url end |
#risk ⇒ Object
Returns the value of attribute risk.
44 45 46 |
# File 'lib/processout/invoice.rb', line 44 def risk @risk end |
#sandbox ⇒ Object
Returns the value of attribute sandbox.
41 42 43 |
# File 'lib/processout/invoice.rb', line 41 def sandbox @sandbox end |
#sca_exemption_reason ⇒ Object
Returns the value of attribute sca_exemption_reason.
49 50 51 |
# File 'lib/processout/invoice.rb', line 49 def sca_exemption_reason @sca_exemption_reason end |
#shipping ⇒ Object
Returns the value of attribute shipping.
45 46 47 |
# File 'lib/processout/invoice.rb', line 45 def shipping @shipping end |
#statement_descriptor ⇒ Object
Returns the value of attribute statement_descriptor.
30 31 32 |
# File 'lib/processout/invoice.rb', line 30 def statement_descriptor @statement_descriptor end |
#statement_descriptor_city ⇒ Object
Returns the value of attribute statement_descriptor_city.
32 33 34 |
# File 'lib/processout/invoice.rb', line 32 def statement_descriptor_city @statement_descriptor_city end |
#statement_descriptor_company ⇒ Object
Returns the value of attribute statement_descriptor_company.
33 34 35 |
# File 'lib/processout/invoice.rb', line 33 def statement_descriptor_company @statement_descriptor_company end |
#statement_descriptor_phone ⇒ Object
Returns the value of attribute statement_descriptor_phone.
31 32 33 |
# File 'lib/processout/invoice.rb', line 31 def statement_descriptor_phone @statement_descriptor_phone end |
#statement_descriptor_url ⇒ Object
Returns the value of attribute statement_descriptor_url.
34 35 36 |
# File 'lib/processout/invoice.rb', line 34 def statement_descriptor_url @statement_descriptor_url end |
#submerchant ⇒ Object
Returns the value of attribute submerchant.
21 22 23 |
# File 'lib/processout/invoice.rb', line 21 def submerchant @submerchant end |
#submerchant_id ⇒ Object
Returns the value of attribute submerchant_id.
22 23 24 |
# File 'lib/processout/invoice.rb', line 22 def submerchant_id @submerchant_id end |
#tax ⇒ Object
Returns the value of attribute tax.
52 53 54 |
# File 'lib/processout/invoice.rb', line 52 def tax @tax end |
#token ⇒ Object
Returns the value of attribute token.
18 19 20 |
# File 'lib/processout/invoice.rb', line 18 def token @token end |
#token_id ⇒ Object
Returns the value of attribute token_id.
19 20 21 |
# File 'lib/processout/invoice.rb', line 19 def token_id @token_id end |
#transaction ⇒ Object
Returns the value of attribute transaction.
14 15 16 |
# File 'lib/processout/invoice.rb', line 14 def transaction @transaction end |
#transaction_id ⇒ Object
Returns the value of attribute transaction_id.
15 16 17 |
# File 'lib/processout/invoice.rb', line 15 def transaction_id @transaction_id end |
#unsupported_feature_bypass ⇒ Object
Returns the value of attribute unsupported_feature_bypass.
58 59 60 |
# File 'lib/processout/invoice.rb', line 58 def unsupported_feature_bypass @unsupported_feature_bypass end |
#url ⇒ Object
Returns the value of attribute url.
23 24 25 |
# File 'lib/processout/invoice.rb', line 23 def url @url end |
#url_qrcode ⇒ Object
Returns the value of attribute url_qrcode.
24 25 26 |
# File 'lib/processout/invoice.rb', line 24 def url_qrcode @url_qrcode end |
#verification ⇒ Object
Returns the value of attribute verification.
59 60 61 |
# File 'lib/processout/invoice.rb', line 59 def verification @verification end |
#webhook_url ⇒ Object
Returns the value of attribute webhook_url.
39 40 41 |
# File 'lib/processout/invoice.rb', line 39 def webhook_url @webhook_url end |
Instance Method Details
#all(options = {}) ⇒ Object
Get all the invoices. Params:
optionsHashof options
1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 |
# File 'lib/processout/invoice.rb', line 1215 def all( = {}) self.prefill() request = Request.new(@client) path = "/invoices" data = { } response = Response.new(request.get(path, data, )) return_values = Array.new a = Array.new body = response.body for v in body['invoices'] tmp = Invoice.new(@client) tmp.fill_with_data(v) a.push(tmp) end return_values.push(a) return_values[0] end |
#assign_customer(customer_id, options = {}) ⇒ Object
Assign a customer to the invoice. Params:
customer_idID of the customer to be linked to the invoice
optionsHashof options
1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 |
# File 'lib/processout/invoice.rb', line 1015 def assign_customer(customer_id, = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(@id) + "/customers" data = { "customer_id" => customer_id } response = Response.new(request.post(path, data, )) return_values = Array.new body = response.body body = body.key?("customer") ? body["customer"] : nil if !body.nil? customer = Customer.new(@client) return_values.push(customer.fill_with_data(body)) end return_values[0] end |
#authenticate(source, options = {}) ⇒ Object
Autheticate the invoice using the given source (customer or token) Params:
sourceSource used to authenticate the payment. Can be a card, token or a gateway request.
optionsHashof options
817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 |
# File 'lib/processout/invoice.rb', line 817 def authenticate(source, = {}) self.prefill() request = Request.new(@client) path = "/invoices/:invoice_id/authenticate" data = { "device" => @device, "incremental" => @incremental, "synchronous" => .fetch(:synchronous, nil), "retry_drop_liability_shift" => .fetch(:retry_drop_liability_shift, nil), "capture_amount" => .fetch(:capture_amount, nil), "enable_three_d_s_2" => .fetch(:enable_three_d_s_2, nil), "allow_fallback_to_sale" => .fetch(:allow_fallback_to_sale, nil), "auto_capture_at" => .fetch(:auto_capture_at, nil), "metadata" => .fetch(:metadata, nil), "override_mac_blocking" => .fetch(:override_mac_blocking, nil), "external_three_d_s" => .fetch(:external_three_d_s, nil), "save_source" => .fetch(:save_source, nil), "provision_network_token" => .fetch(:provision_network_token, nil), "invoice_line_items" => .fetch(:invoice_line_items, nil), "transaction_link_id" => .fetch(:transaction_link_id, nil), "source" => source } response = Response.new(request.post(path, data, )) return_values = Array.new body = response.body body = body.key?("transaction") ? body["transaction"] : nil if !body.nil? transaction = Transaction.new(@client) return_values.push(transaction.fill_with_data(body)) end body = response.body body = body.key?("customer_action") ? body["customer_action"] : nil if !body.nil? customer_action = CustomerAction.new(@client) return_values.push(customer_action.fill_with_data(body)) end return_values end |
#authorize(source, options = {}) ⇒ Object
Authorize the invoice using the given source (customer or token) Params:
sourceSource used to authorization the payment. Can be a card, a token or a gateway request
optionsHashof options
893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 |
# File 'lib/processout/invoice.rb', line 893 def (source, = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(@id) + "/authorize" data = { "device" => @device, "incremental" => @incremental, "synchronous" => .fetch(:synchronous, nil), "retry_drop_liability_shift" => .fetch(:retry_drop_liability_shift, nil), "capture_amount" => .fetch(:capture_amount, nil), "enable_three_d_s_2" => .fetch(:enable_three_d_s_2, nil), "allow_fallback_to_sale" => .fetch(:allow_fallback_to_sale, nil), "auto_capture_at" => .fetch(:auto_capture_at, nil), "metadata" => .fetch(:metadata, nil), "override_mac_blocking" => .fetch(:override_mac_blocking, nil), "external_three_d_s" => .fetch(:external_three_d_s, nil), "save_source" => .fetch(:save_source, nil), "provision_network_token" => .fetch(:provision_network_token, nil), "invoice_line_items" => .fetch(:invoice_line_items, nil), "transaction_link_id" => .fetch(:transaction_link_id, nil), "source" => source } response = Response.new(request.post(path, data, )) return_values = Array.new body = response.body body = body.key?("transaction") ? body["transaction"] : nil if !body.nil? transaction = Transaction.new(@client) return_values.push(transaction.fill_with_data(body)) end body = response.body body = body.key?("customer_action") ? body["customer_action"] : nil if !body.nil? customer_action = CustomerAction.new(@client) return_values.push(customer_action.fill_with_data(body)) end return_values end |
#capture(source, options = {}) ⇒ Object
Capture the invoice using the given source (customer or token) Params:
sourceSource used to authorization the payment. Can be a card, a token or a gateway request
optionsHashof options
941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 |
# File 'lib/processout/invoice.rb', line 941 def capture(source, = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(@id) + "/capture" data = { "device" => @device, "incremental" => @incremental, "authorize_only" => .fetch(:authorize_only, nil), "synchronous" => .fetch(:synchronous, nil), "retry_drop_liability_shift" => .fetch(:retry_drop_liability_shift, nil), "capture_amount" => .fetch(:capture_amount, nil), "auto_capture_at" => .fetch(:auto_capture_at, nil), "enable_three_d_s_2" => .fetch(:enable_three_d_s_2, nil), "metadata" => .fetch(:metadata, nil), "capture_statement_descriptor" => .fetch(:capture_statement_descriptor, nil), "override_mac_blocking" => .fetch(:override_mac_blocking, nil), "external_three_d_s" => .fetch(:external_three_d_s, nil), "save_source" => .fetch(:save_source, nil), "provision_network_token" => .fetch(:provision_network_token, nil), "transaction_link_id" => .fetch(:transaction_link_id, nil), "source" => source } response = Response.new(request.post(path, data, )) return_values = Array.new body = response.body body = body.key?("transaction") ? body["transaction"] : nil if !body.nil? transaction = Transaction.new(@client) return_values.push(transaction.fill_with_data(body)) end body = response.body body = body.key?("customer_action") ? body["customer_action"] : nil if !body.nil? customer_action = CustomerAction.new(@client) return_values.push(customer_action.fill_with_data(body)) end return_values end |
#create(options = {}) ⇒ Object
Create a new invoice. Params:
optionsHashof options
1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 |
# File 'lib/processout/invoice.rb', line 1245 def create( = {}) self.prefill() request = Request.new(@client) path = "/invoices" data = { "customer_id" => @customer_id, "name" => @name, "order_id" => @order_id, "amount" => @amount, "currency" => @currency, "metadata" => @metadata, "details" => @details, "submerchant" => @submerchant, "submerchant_id" => @submerchant_id, "reference_id" => @reference_id, "exemption_reason_3ds2" => @exemption_reason_3ds2, "sca_exemption_reason" => @sca_exemption_reason, "challenge_indicator" => @challenge_indicator, "gateway_data" => @gateway_data, "merchant_initiator_type" => @merchant_initiator_type, "initiation_type" => @initiation_type, "payment_intent" => @payment_intent, "statement_descriptor" => @statement_descriptor, "statement_descriptor_phone" => @statement_descriptor_phone, "statement_descriptor_city" => @statement_descriptor_city, "statement_descriptor_company" => @statement_descriptor_company, "statement_descriptor_url" => @statement_descriptor_url, "return_url" => @return_url, "cancel_url" => @cancel_url, "webhook_url" => @webhook_url, "risk" => @risk, "shipping" => @shipping, "device" => @device, "require_backend_capture" => @require_backend_capture, "external_fraud_tools" => @external_fraud_tools, "tax" => @tax, "payment_type" => @payment_type, "billing" => @billing, "unsupported_feature_bypass" => @unsupported_feature_bypass, "verification" => @verification, "auto_capture_at" => @auto_capture_at, "expires_at" => @expires_at } response = Response.new(request.post(path, data, )) return_values = Array.new body = response.body body = body.key?("invoice") ? body["invoice"] : nil return_values.push(self.fill_with_data(body)) return_values[0] end |
#delete(invoice_id, options = {}) ⇒ Object
Delete an invoice by its ID. Only invoices that have not been used yet can be deleted. Params:
invoice_idID of the invoice
optionsHashof options
1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 |
# File 'lib/processout/invoice.rb', line 1336 def delete(invoice_id, = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(invoice_id) + "" data = { } response = Response.new(request.delete(path, data, )) return_values = Array.new return_values.push(response.success) return_values[0] end |
#fetch_customer(options = {}) ⇒ Object
Get the customer linked to the invoice. Params:
optionsHashof options
988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 |
# File 'lib/processout/invoice.rb', line 988 def fetch_customer( = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(@id) + "/customers" data = { } response = Response.new(request.get(path, data, )) return_values = Array.new body = response.body body = body.key?("customer") ? body["customer"] : nil if !body.nil? customer = Customer.new(@client) return_values.push(customer.fill_with_data(body)) end return_values[0] end |
#fetch_transaction(options = {}) ⇒ Object
Get the transaction of the invoice. Params:
optionsHashof options
1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 |
# File 'lib/processout/invoice.rb', line 1162 def fetch_transaction( = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(@id) + "/transactions" data = { } response = Response.new(request.get(path, data, )) return_values = Array.new body = response.body body = body.key?("transaction") ? body["transaction"] : nil if !body.nil? transaction = Transaction.new(@client) return_values.push(transaction.fill_with_data(body)) end return_values[0] end |
#fill_with_data(data) ⇒ Object
Fills the object with data coming from the API Params:
dataHashof data coming from the API
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 |
# File 'lib/processout/invoice.rb', line 586 def fill_with_data(data) if data.nil? return self end if data.include? "id" self.id = data["id"] end if data.include? "project" self.project = data["project"] end if data.include? "project_id" self.project_id = data["project_id"] end if data.include? "transaction" self.transaction = data["transaction"] end if data.include? "transaction_id" self.transaction_id = data["transaction_id"] end if data.include? "customer" self.customer = data["customer"] end if data.include? "customer_id" self.customer_id = data["customer_id"] end if data.include? "token" self.token = data["token"] end if data.include? "token_id" self.token_id = data["token_id"] end if data.include? "details" self.details = data["details"] end if data.include? "submerchant" self.submerchant = data["submerchant"] end if data.include? "submerchant_id" self.submerchant_id = data["submerchant_id"] end if data.include? "url" self.url = data["url"] end if data.include? "url_qrcode" self.url_qrcode = data["url_qrcode"] end if data.include? "name" self.name = data["name"] end if data.include? "order_id" self.order_id = data["order_id"] end if data.include? "amount" self.amount = data["amount"] end if data.include? "currency" self.currency = data["currency"] end if data.include? "merchant_initiator_type" self.merchant_initiator_type = data["merchant_initiator_type"] end if data.include? "statement_descriptor" self.statement_descriptor = data["statement_descriptor"] end if data.include? "statement_descriptor_phone" self.statement_descriptor_phone = data["statement_descriptor_phone"] end if data.include? "statement_descriptor_city" self.statement_descriptor_city = data["statement_descriptor_city"] end if data.include? "statement_descriptor_company" self.statement_descriptor_company = data["statement_descriptor_company"] end if data.include? "statement_descriptor_url" self.statement_descriptor_url = data["statement_descriptor_url"] end if data.include? "metadata" self. = data["metadata"] end if data.include? "gateway_data" self.gateway_data = data["gateway_data"] end if data.include? "return_url" self.return_url = data["return_url"] end if data.include? "cancel_url" self.cancel_url = data["cancel_url"] end if data.include? "webhook_url" self.webhook_url = data["webhook_url"] end if data.include? "require_backend_capture" self.require_backend_capture = data["require_backend_capture"] end if data.include? "sandbox" self.sandbox = data["sandbox"] end if data.include? "created_at" self.created_at = data["created_at"] end if data.include? "expires_at" self.expires_at = data["expires_at"] end if data.include? "risk" self.risk = data["risk"] end if data.include? "shipping" self.shipping = data["shipping"] end if data.include? "device" self.device = data["device"] end if data.include? "external_fraud_tools" self.external_fraud_tools = data["external_fraud_tools"] end if data.include? "exemption_reason_3ds2" self.exemption_reason_3ds2 = data["exemption_reason_3ds2"] end if data.include? "sca_exemption_reason" self.sca_exemption_reason = data["sca_exemption_reason"] end if data.include? "challenge_indicator" self.challenge_indicator = data["challenge_indicator"] end if data.include? "incremental" self.incremental = data["incremental"] end if data.include? "tax" self.tax = data["tax"] end if data.include? "payment_type" self.payment_type = data["payment_type"] end if data.include? "native_apm" self.native_apm = data["native_apm"] end if data.include? "initiation_type" self.initiation_type = data["initiation_type"] end if data.include? "payment_intent" self.payment_intent = data["payment_intent"] end if data.include? "billing" self.billing = data["billing"] end if data.include? "unsupported_feature_bypass" self.unsupported_feature_bypass = data["unsupported_feature_bypass"] end if data.include? "verification" self.verification = data["verification"] end if data.include? "auto_capture_at" self.auto_capture_at = data["auto_capture_at"] end if data.include? "reference_id" self.reference_id = data["reference_id"] end if data.include? "payment_processing_config" self.payment_processing_config = data["payment_processing_config"] end self end |
#find(invoice_id, options = {}) ⇒ Object
Find an invoice by its ID. Params:
invoice_idID of the invoice
optionsHashof options
1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 |
# File 'lib/processout/invoice.rb', line 1308 def find(invoice_id, = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(invoice_id) + "" data = { } response = Response.new(request.get(path, data, )) return_values = Array.new body = response.body body = body.key?("invoice") ? body["invoice"] : nil obj = Invoice.new(@client) return_values.push(obj.fill_with_data(body)) return_values[0] end |
#increment_authorization(amount, options = {}) ⇒ Object
Create an incremental authorization Params:
amountAmount to increment authorization by
optionsHashof options
865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 |
# File 'lib/processout/invoice.rb', line 865 def (amount, = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(@id) + "/increment_authorization" data = { "metadata" => .fetch(:metadata, nil), "amount" => amount } response = Response.new(request.post(path, data, )) return_values = Array.new body = response.body body = body.key?("transaction") ? body["transaction"] : nil if !body.nil? transaction = Transaction.new(@client) return_values.push(transaction.fill_with_data(body)) end return_values[0] end |
#initiate_three_d_s(source, options = {}) ⇒ Object
Initiate a 3-D Secure authentication Params:
sourceSource used to initiate the 3-D Secure authentication. Can be a card, or a token representing a card
optionsHashof options
1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 |
# File 'lib/processout/invoice.rb', line 1135 def initiate_three_d_s(source, = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(@id) + "/three-d-s" data = { "enable_three_d_s_2" => .fetch(:enable_three_d_s_2, nil), "source" => source } response = Response.new(request.post(path, data, )) return_values = Array.new body = response.body body = body.key?("customer_action") ? body["customer_action"] : nil if !body.nil? customer_action = CustomerAction.new(@client) return_values.push(customer_action.fill_with_data(body)) end return_values[0] end |
#new(data = {}) ⇒ Object
Create a new Invoice using the current client
521 522 523 |
# File 'lib/processout/invoice.rb', line 521 def new(data = {}) Invoice.new(@client, data) end |
#payout(gateway_configuration_id, source, options = {}) ⇒ Object
Process the payout invoice using the given source (customer or token) Params:
gateway_configuration_idID of the configuration, that processes payout
sourceSource used to process the payout. Can be a card, a token or a gateway request
optionsHashof options
1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 |
# File 'lib/processout/invoice.rb', line 1043 def payout(gateway_configuration_id, source, = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(@id) + "/payout" data = { "force_gateway_configuration_id" => .fetch(:force_gateway_configuration_id, nil), "metadata" => .fetch(:metadata, nil), "gateway_configuration_id" => gateway_configuration_id, "source" => source } response = Response.new(request.post(path, data, )) return_values = Array.new body = response.body body = body.key?("transaction") ? body["transaction"] : nil if !body.nil? transaction = Transaction.new(@client) return_values.push(transaction.fill_with_data(body)) end return_values[0] end |
#prefill(data) ⇒ Object
Prefills the object with the data passed as parameters Params:
dataHashof data
753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 |
# File 'lib/processout/invoice.rb', line 753 def prefill(data) if data.nil? return self end self.id = data.fetch(:id, self.id) self.project = data.fetch(:project, self.project) self.project_id = data.fetch(:project_id, self.project_id) self.transaction = data.fetch(:transaction, self.transaction) self.transaction_id = data.fetch(:transaction_id, self.transaction_id) self.customer = data.fetch(:customer, self.customer) self.customer_id = data.fetch(:customer_id, self.customer_id) self.token = data.fetch(:token, self.token) self.token_id = data.fetch(:token_id, self.token_id) self.details = data.fetch(:details, self.details) self.submerchant = data.fetch(:submerchant, self.submerchant) self.submerchant_id = data.fetch(:submerchant_id, self.submerchant_id) self.url = data.fetch(:url, self.url) self.url_qrcode = data.fetch(:url_qrcode, self.url_qrcode) self.name = data.fetch(:name, self.name) self.order_id = data.fetch(:order_id, self.order_id) self.amount = data.fetch(:amount, self.amount) self.currency = data.fetch(:currency, self.currency) self.merchant_initiator_type = data.fetch(:merchant_initiator_type, self.merchant_initiator_type) self.statement_descriptor = data.fetch(:statement_descriptor, self.statement_descriptor) self.statement_descriptor_phone = data.fetch(:statement_descriptor_phone, self.statement_descriptor_phone) self.statement_descriptor_city = data.fetch(:statement_descriptor_city, self.statement_descriptor_city) self.statement_descriptor_company = data.fetch(:statement_descriptor_company, self.statement_descriptor_company) self.statement_descriptor_url = data.fetch(:statement_descriptor_url, self.statement_descriptor_url) self. = data.fetch(:metadata, self.) self.gateway_data = data.fetch(:gateway_data, self.gateway_data) self.return_url = data.fetch(:return_url, self.return_url) self.cancel_url = data.fetch(:cancel_url, self.cancel_url) self.webhook_url = data.fetch(:webhook_url, self.webhook_url) self.require_backend_capture = data.fetch(:require_backend_capture, self.require_backend_capture) self.sandbox = data.fetch(:sandbox, self.sandbox) self.created_at = data.fetch(:created_at, self.created_at) self.expires_at = data.fetch(:expires_at, self.expires_at) self.risk = data.fetch(:risk, self.risk) self.shipping = data.fetch(:shipping, self.shipping) self.device = data.fetch(:device, self.device) self.external_fraud_tools = data.fetch(:external_fraud_tools, self.external_fraud_tools) self.exemption_reason_3ds2 = data.fetch(:exemption_reason_3ds2, self.exemption_reason_3ds2) self.sca_exemption_reason = data.fetch(:sca_exemption_reason, self.sca_exemption_reason) self.challenge_indicator = data.fetch(:challenge_indicator, self.challenge_indicator) self.incremental = data.fetch(:incremental, self.incremental) self.tax = data.fetch(:tax, self.tax) self.payment_type = data.fetch(:payment_type, self.payment_type) self.native_apm = data.fetch(:native_apm, self.native_apm) self.initiation_type = data.fetch(:initiation_type, self.initiation_type) self.payment_intent = data.fetch(:payment_intent, self.payment_intent) self.billing = data.fetch(:billing, self.billing) self.unsupported_feature_bypass = data.fetch(:unsupported_feature_bypass, self.unsupported_feature_bypass) self.verification = data.fetch(:verification, self.verification) self.auto_capture_at = data.fetch(:auto_capture_at, self.auto_capture_at) self.reference_id = data.fetch(:reference_id, self.reference_id) self.payment_processing_config = data.fetch(:payment_processing_config, self.payment_processing_config) self end |
#process_native_payment(invoice_id, options = {}) ⇒ Object
Process the Native APM payment flow Params:
invoice_idID of the invoice
optionsHashof options
1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 |
# File 'lib/processout/invoice.rb', line 1101 def process_native_payment(invoice_id, = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(invoice_id) + "/native-payment" data = { "gateway_configuration_id" => .fetch(:gateway_configuration_id, nil), "native_apm" => .fetch(:native_apm, nil) } response = Response.new(request.post(path, data, )) return_values = Array.new body = response.body body = body.key?("transaction") ? body["transaction"] : nil if !body.nil? transaction = Transaction.new(@client) return_values.push(transaction.fill_with_data(body)) end body = response.body body = body.key?("native_apm") ? body["native_apm"] : nil if !body.nil? native_apm_response = NativeAPMResponse.new(@client) return_values.push(native_apm_response.fill_with_data(body)) end return_values end |
#show_native_payment_transaction(invoice_id, gateway_configuration_id, options = {}) ⇒ Object
Fetches the Native APM payment Params:
invoice_idID of the invoice
gateway_configuration_idID of the native APM configuration
optionsHashof options
1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 |
# File 'lib/processout/invoice.rb', line 1074 def show_native_payment_transaction(invoice_id, gateway_configuration_id, = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(invoice_id) + "/native-payment/" + CGI.escape(gateway_configuration_id) + "" data = { } response = Response.new(request.get(path, data, )) return_values = Array.new body = response.body body = body.key?("native_apm") ? body["native_apm"] : nil if !body.nil? native_apm_transaction_details = NativeAPMTransactionDetails.new(@client) return_values.push(native_apm_transaction_details.fill_with_data(body)) end return_values[0] end |
#sync_with_psp(invoice_id, options = {}) ⇒ Object
Refresh invoice by its ID with PSP. Params:
invoice_idID of the invoice
optionsHashof options
1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 |
# File 'lib/processout/invoice.rb', line 1358 def sync_with_psp(invoice_id, = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(invoice_id) + "/sync-with-psp" data = { } response = Response.new(request.put(path, data, )) return_values = Array.new body = response.body body = body.key?("invoice") ? body["invoice"] : nil obj = Invoice.new(@client) return_values.push(obj.fill_with_data(body)) return_values[0] end |
#to_json(options) ⇒ Object
Overrides the JSON marshaller to only send the fields we want
526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 |
# File 'lib/processout/invoice.rb', line 526 def to_json() { "id": self.id, "project": self.project, "project_id": self.project_id, "transaction": self.transaction, "transaction_id": self.transaction_id, "customer": self.customer, "customer_id": self.customer_id, "token": self.token, "token_id": self.token_id, "details": self.details, "submerchant": self.submerchant, "submerchant_id": self.submerchant_id, "url": self.url, "url_qrcode": self.url_qrcode, "name": self.name, "order_id": self.order_id, "amount": self.amount, "currency": self.currency, "merchant_initiator_type": self.merchant_initiator_type, "statement_descriptor": self.statement_descriptor, "statement_descriptor_phone": self.statement_descriptor_phone, "statement_descriptor_city": self.statement_descriptor_city, "statement_descriptor_company": self.statement_descriptor_company, "statement_descriptor_url": self.statement_descriptor_url, "metadata": self., "gateway_data": self.gateway_data, "return_url": self.return_url, "cancel_url": self.cancel_url, "webhook_url": self.webhook_url, "require_backend_capture": self.require_backend_capture, "sandbox": self.sandbox, "created_at": self.created_at, "expires_at": self.expires_at, "risk": self.risk, "shipping": self.shipping, "device": self.device, "external_fraud_tools": self.external_fraud_tools, "exemption_reason_3ds2": self.exemption_reason_3ds2, "sca_exemption_reason": self.sca_exemption_reason, "challenge_indicator": self.challenge_indicator, "incremental": self.incremental, "tax": self.tax, "payment_type": self.payment_type, "native_apm": self.native_apm, "initiation_type": self.initiation_type, "payment_intent": self.payment_intent, "billing": self.billing, "unsupported_feature_bypass": self.unsupported_feature_bypass, "verification": self.verification, "auto_capture_at": self.auto_capture_at, "reference_id": self.reference_id, "payment_processing_config": self.payment_processing_config, }.to_json end |
#update(invoice_id, options = {}) ⇒ Object
Update invoice by its ID. Params:
invoice_idID of the invoice
optionsHashof options
1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 |
# File 'lib/processout/invoice.rb', line 1386 def update(invoice_id, = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(invoice_id) + "" data = { "amount" => @amount, "tax" => @tax, "details" => @details, "shipping" => @shipping } response = Response.new(request.put(path, data, )) return_values = Array.new body = response.body body = body.key?("invoice") ? body["invoice"] : nil return_values.push(self.fill_with_data(body)) return_values[0] end |
#void(options = {}) ⇒ Object
Void the invoice Params:
optionsHashof options
1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 |
# File 'lib/processout/invoice.rb', line 1188 def void( = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(@id) + "/void" data = { "metadata" => .fetch(:metadata, nil), "amount" => .fetch(:amount, nil) } response = Response.new(request.post(path, data, )) return_values = Array.new body = response.body body = body.key?("transaction") ? body["transaction"] : nil if !body.nil? transaction = Transaction.new(@client) return_values.push(transaction.fill_with_data(body)) end return_values[0] end |