Class: ProcessOut::Invoice

Inherits:
Object
  • Object
show all
Defined in:
lib/processout/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client, data = {}) ⇒ Invoice

Initializes the Invoice object Params:

client

ProcessOut client instance

data

data that can be used to fill the object



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/processout/invoice.rb', line 327

def initialize(client, data = {})
  @client = client

  self.id = data.fetch(:id, nil)
  self.project = data.fetch(:project, nil)
  self.project_id = data.fetch(:project_id, nil)
  self.transaction = data.fetch(:transaction, nil)
  self.transaction_id = data.fetch(:transaction_id, nil)
  self.customer = data.fetch(:customer, nil)
  self.customer_id = data.fetch(:customer_id, nil)
  self.subscription = data.fetch(:subscription, nil)
  self.subscription_id = data.fetch(:subscription_id, nil)
  self.token = data.fetch(:token, nil)
  self.token_id = data.fetch(:token_id, nil)
  self.details = data.fetch(:details, nil)
  self.url = data.fetch(:url, nil)
  self.name = data.fetch(:name, nil)
  self.amount = data.fetch(:amount, nil)
  self.currency = data.fetch(:currency, nil)
  self.merchant_initiator_type = data.fetch(:merchant_initiator_type, nil)
  self.statement_descriptor = data.fetch(:statement_descriptor, nil)
  self.statement_descriptor_phone = data.fetch(:statement_descriptor_phone, nil)
  self.statement_descriptor_city = data.fetch(:statement_descriptor_city, nil)
  self.statement_descriptor_company = data.fetch(:statement_descriptor_company, nil)
  self.statement_descriptor_url = data.fetch(:statement_descriptor_url, nil)
  self. = data.fetch(:metadata, nil)
  self.gateway_data = data.fetch(:gateway_data, nil)
  self.return_url = data.fetch(:return_url, nil)
  self.cancel_url = data.fetch(:cancel_url, nil)
  self.webhook_url = data.fetch(:webhook_url, nil)
  self.require_backend_capture = data.fetch(:require_backend_capture, nil)
  self.sandbox = data.fetch(:sandbox, nil)
  self.created_at = data.fetch(:created_at, nil)
  self.risk = data.fetch(:risk, nil)
  self.shipping = data.fetch(:shipping, nil)
  self.device = data.fetch(:device, nil)
  self.external_fraud_tools = data.fetch(:external_fraud_tools, nil)
  self.exemption_reason_3ds2 = data.fetch(:exemption_reason_3ds2, nil)
  self.sca_exemption_reason = data.fetch(:sca_exemption_reason, nil)
  self.challenge_indicator = data.fetch(:challenge_indicator, nil)
  
end

Instance Attribute Details

#amount ⇒ Object

Returns the value of attribute amount.



25
26
27
# File 'lib/processout/invoice.rb', line 25

def amount
  @amount
end

#cancel_url ⇒ Object

Returns the value of attribute cancel_url.



36
37
38
# File 'lib/processout/invoice.rb', line 36

def cancel_url
  @cancel_url
end

#challenge_indicator ⇒ Object

Returns the value of attribute challenge_indicator.



47
48
49
# File 'lib/processout/invoice.rb', line 47

def challenge_indicator
  @challenge_indicator
end

#created_at ⇒ Object

Returns the value of attribute created_at.



40
41
42
# File 'lib/processout/invoice.rb', line 40

def created_at
  @created_at
end

#currency ⇒ Object

Returns the value of attribute currency.



26
27
28
# File 'lib/processout/invoice.rb', line 26

def currency
  @currency
end

#customer ⇒ Object

Returns the value of attribute customer.



16
17
18
# File 'lib/processout/invoice.rb', line 16

def customer
  @customer
end

#customer_id ⇒ Object

Returns the value of attribute customer_id.



17
18
19
# File 'lib/processout/invoice.rb', line 17

def customer_id
  @customer_id
end

#details ⇒ Object

Returns the value of attribute details.



22
23
24
# File 'lib/processout/invoice.rb', line 22

def details
  @details
end

#device ⇒ Object

Returns the value of attribute device.



43
44
45
# File 'lib/processout/invoice.rb', line 43

def device
  @device
end

#exemption_reason_3ds2 ⇒ Object

Returns the value of attribute exemption_reason_3ds2.



45
46
47
# File 'lib/processout/invoice.rb', line 45

def exemption_reason_3ds2
  @exemption_reason_3ds2
end

#external_fraud_tools ⇒ Object

Returns the value of attribute external_fraud_tools.



44
45
46
# File 'lib/processout/invoice.rb', line 44

def external_fraud_tools
  @external_fraud_tools
end

#gateway_data ⇒ Object

Returns the value of attribute gateway_data.



34
35
36
# File 'lib/processout/invoice.rb', line 34

def gateway_data
  @gateway_data
end

#id ⇒ Object

Returns the value of attribute id.



11
12
13
# File 'lib/processout/invoice.rb', line 11

def id
  @id
end

#merchant_initiator_type ⇒ Object

Returns the value of attribute merchant_initiator_type.



27
28
29
# File 'lib/processout/invoice.rb', line 27

def merchant_initiator_type
  @merchant_initiator_type
end

#metadata ⇒ Object

Returns the value of attribute metadata.



33
34
35
# File 'lib/processout/invoice.rb', line 33

def 
  @metadata
end

#name ⇒ Object

Returns the value of attribute name.



24
25
26
# File 'lib/processout/invoice.rb', line 24

def name
  @name
end

#project ⇒ Object

Returns the value of attribute project.



12
13
14
# File 'lib/processout/invoice.rb', line 12

def project
  @project
end

#project_id ⇒ Object

Returns the value of attribute project_id.



13
14
15
# File 'lib/processout/invoice.rb', line 13

def project_id
  @project_id
end

#require_backend_capture ⇒ Object

Returns the value of attribute require_backend_capture.



38
39
40
# File 'lib/processout/invoice.rb', line 38

def require_backend_capture
  @require_backend_capture
end

#return_url ⇒ Object

Returns the value of attribute return_url.



35
36
37
# File 'lib/processout/invoice.rb', line 35

def return_url
  @return_url
end

#risk ⇒ Object

Returns the value of attribute risk.



41
42
43
# File 'lib/processout/invoice.rb', line 41

def risk
  @risk
end

#sandbox ⇒ Object

Returns the value of attribute sandbox.



39
40
41
# File 'lib/processout/invoice.rb', line 39

def sandbox
  @sandbox
end

#sca_exemption_reason ⇒ Object

Returns the value of attribute sca_exemption_reason.



46
47
48
# File 'lib/processout/invoice.rb', line 46

def sca_exemption_reason
  @sca_exemption_reason
end

#shipping ⇒ Object

Returns the value of attribute shipping.



42
43
44
# File 'lib/processout/invoice.rb', line 42

def shipping
  @shipping
end

#statement_descriptor ⇒ Object

Returns the value of attribute statement_descriptor.



28
29
30
# File 'lib/processout/invoice.rb', line 28

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_city ⇒ Object

Returns the value of attribute statement_descriptor_city.



30
31
32
# File 'lib/processout/invoice.rb', line 30

def statement_descriptor_city
  @statement_descriptor_city
end

#statement_descriptor_company ⇒ Object

Returns the value of attribute statement_descriptor_company.



31
32
33
# File 'lib/processout/invoice.rb', line 31

def statement_descriptor_company
  @statement_descriptor_company
end

#statement_descriptor_phone ⇒ Object

Returns the value of attribute statement_descriptor_phone.



29
30
31
# File 'lib/processout/invoice.rb', line 29

def statement_descriptor_phone
  @statement_descriptor_phone
end

#statement_descriptor_url ⇒ Object

Returns the value of attribute statement_descriptor_url.



32
33
34
# File 'lib/processout/invoice.rb', line 32

def statement_descriptor_url
  @statement_descriptor_url
end

#subscription ⇒ Object

Returns the value of attribute subscription.



18
19
20
# File 'lib/processout/invoice.rb', line 18

def subscription
  @subscription
end

#subscription_id ⇒ Object

Returns the value of attribute subscription_id.



19
20
21
# File 'lib/processout/invoice.rb', line 19

def subscription_id
  @subscription_id
end

#token ⇒ Object

Returns the value of attribute token.



20
21
22
# File 'lib/processout/invoice.rb', line 20

def token
  @token
end

#token_id ⇒ Object

Returns the value of attribute token_id.



21
22
23
# File 'lib/processout/invoice.rb', line 21

def token_id
  @token_id
end

#transaction ⇒ Object

Returns the value of attribute transaction.



14
15
16
# File 'lib/processout/invoice.rb', line 14

def transaction
  @transaction
end

#transaction_id ⇒ Object

Returns the value of attribute transaction_id.



15
16
17
# File 'lib/processout/invoice.rb', line 15

def transaction_id
  @transaction_id
end

#url ⇒ Object

Returns the value of attribute url.



23
24
25
# File 'lib/processout/invoice.rb', line 23

def url
  @url
end

#webhook_url ⇒ Object

Returns the value of attribute webhook_url.



37
38
39
# File 'lib/processout/invoice.rb', line 37

def webhook_url
  @webhook_url
end

Instance Method Details

#all(options = {}) ⇒ Object

Get all the invoices. Params:

options

Hash of options



777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
# File 'lib/processout/invoice.rb', line 777

def all(options = {})
  self.prefill(options)

  request = Request.new(@client)
  path    = "/invoices"
  data    = {

  }

  response = Response.new(request.get(path, data, options))
  return_values = Array.new
  
  a    = Array.new
  body = response.body
  for v in body['invoices']
    tmp = Invoice.new(@client)
    tmp.fill_with_data(v)
    a.push(tmp)
  end

  return_values.push(a)
  

  
  return_values[0]
end

#assign_customer(customer_id, options = {}) ⇒ Object

Assign a customer to the invoice. Params:

customer_id

ID of the customer to be linked to the invoice

options

Hash of options



679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
# File 'lib/processout/invoice.rb', line 679

def assign_customer(customer_id, options = {})
  self.prefill(options)

  request = Request.new(@client)
  path    = "/invoices/" + CGI.escape(@id) + "/customers"
  data    = {
    "customer_id" => customer_id
  }

  response = Response.new(request.post(path, data, options))
  return_values = Array.new
  
  body = response.body
  body = body["customer"]
  customer = Customer.new(@client)
  return_values.push(customer.fill_with_data(body))

  
  return_values[0]
end

#authorize(source, options = {}) ⇒ Object

Authorize the invoice using the given source (customer or token) Params:

source

Source used to authorization the payment. Can be a card, a token or a gateway request

options

Hash of options



592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
# File 'lib/processout/invoice.rb', line 592

def authorize(source, options = {})
  self.prefill(options)

  request = Request.new(@client)
  path    = "/invoices/" + CGI.escape(@id) + "/authorize"
  data    = {
    "device" => @device, 
    "synchronous" => options.fetch(:synchronous, nil), 
    "retry_drop_liability_shift" => options.fetch(:retry_drop_liability_shift, nil), 
    "capture_amount" => options.fetch(:capture_amount, nil), 
    "enable_three_d_s_2" => options.fetch(:enable_three_d_s_2, nil), 
    "auto_capture_at" => options.fetch(:auto_capture_at, nil), 
    "source" => source
  }

  response = Response.new(request.post(path, data, options))
  return_values = Array.new
  
  body = response.body
  body = body["transaction"]
  transaction = Transaction.new(@client)
  return_values.push(transaction.fill_with_data(body))

  
  return_values[0]
end

#capture(source, options = {}) ⇒ Object

Capture the invoice using the given source (customer or token) Params:

source

Source used to authorization the payment. Can be a card, a token or a gateway request

options

Hash of options



623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
# File 'lib/processout/invoice.rb', line 623

def capture(source, options = {})
  self.prefill(options)

  request = Request.new(@client)
  path    = "/invoices/" + CGI.escape(@id) + "/capture"
  data    = {
    "device" => @device, 
    "authorize_only" => options.fetch(:authorize_only, nil), 
    "synchronous" => options.fetch(:synchronous, nil), 
    "retry_drop_liability_shift" => options.fetch(:retry_drop_liability_shift, nil), 
    "capture_amount" => options.fetch(:capture_amount, nil), 
    "auto_capture_at" => options.fetch(:auto_capture_at, nil), 
    "enable_three_d_s_2" => options.fetch(:enable_three_d_s_2, nil), 
    "source" => source
  }

  response = Response.new(request.post(path, data, options))
  return_values = Array.new
  
  body = response.body
  body = body["transaction"]
  transaction = Transaction.new(@client)
  return_values.push(transaction.fill_with_data(body))

  
  return_values[0]
end

#create(options = {}) ⇒ Object

Create a new invoice. Params:

options

Hash of options



807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
# File 'lib/processout/invoice.rb', line 807

def create(options = {})
  self.prefill(options)

  request = Request.new(@client)
  path    = "/invoices"
  data    = {
    "customer_id" => @customer_id, 
    "name" => @name, 
    "amount" => @amount, 
    "currency" => @currency, 
    "metadata" => @metadata, 
    "details" => @details, 
    "exemption_reason_3ds2" => @exemption_reason_3ds2, 
    "sca_exemption_reason" => @sca_exemption_reason, 
    "challenge_indicator" => @challenge_indicator, 
    "gateway_data" => @gateway_data, 
    "merchant_initiator_type" => @merchant_initiator_type, 
    "statement_descriptor" => @statement_descriptor, 
    "statement_descriptor_phone" => @statement_descriptor_phone, 
    "statement_descriptor_city" => @statement_descriptor_city, 
    "statement_descriptor_company" => @statement_descriptor_company, 
    "statement_descriptor_url" => @statement_descriptor_url, 
    "return_url" => @return_url, 
    "cancel_url" => @cancel_url, 
    "webhook_url" => @webhook_url, 
    "risk" => @risk, 
    "shipping" => @shipping, 
    "device" => @device, 
    "require_backend_capture" => @require_backend_capture, 
    "external_fraud_tools" => @external_fraud_tools
  }

  response = Response.new(request.post(path, data, options))
  return_values = Array.new
  
  body = response.body
  body = body["invoice"]
  
  
  return_values.push(self.fill_with_data(body))
  

  
  return_values[0]
end

#fetch_customer(options = {}) ⇒ Object

Get the customer linked to the invoice. Params:

options

Hash of options



654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
# File 'lib/processout/invoice.rb', line 654

def fetch_customer(options = {})
  self.prefill(options)

  request = Request.new(@client)
  path    = "/invoices/" + CGI.escape(@id) + "/customers"
  data    = {

  }

  response = Response.new(request.get(path, data, options))
  return_values = Array.new
  
  body = response.body
  body = body["customer"]
  customer = Customer.new(@client)
  return_values.push(customer.fill_with_data(body))

  
  return_values[0]
end

#fetch_transaction(options = {}) ⇒ Object

Get the transaction of the invoice. Params:

options

Hash of options



729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
# File 'lib/processout/invoice.rb', line 729

def fetch_transaction(options = {})
  self.prefill(options)

  request = Request.new(@client)
  path    = "/invoices/" + CGI.escape(@id) + "/transactions"
  data    = {

  }

  response = Response.new(request.get(path, data, options))
  return_values = Array.new
  
  body = response.body
  body = body["transaction"]
  transaction = Transaction.new(@client)
  return_values.push(transaction.fill_with_data(body))

  
  return_values[0]
end

#fill_with_data(data) ⇒ Object

Fills the object with data coming from the API Params:

data

Hash of data coming from the API



421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
# File 'lib/processout/invoice.rb', line 421

def fill_with_data(data)
  if data.nil?
    return self
  end
  if data.include? "id"
    self.id = data["id"]
  end
  if data.include? "project"
    self.project = data["project"]
  end
  if data.include? "project_id"
    self.project_id = data["project_id"]
  end
  if data.include? "transaction"
    self.transaction = data["transaction"]
  end
  if data.include? "transaction_id"
    self.transaction_id = data["transaction_id"]
  end
  if data.include? "customer"
    self.customer = data["customer"]
  end
  if data.include? "customer_id"
    self.customer_id = data["customer_id"]
  end
  if data.include? "subscription"
    self.subscription = data["subscription"]
  end
  if data.include? "subscription_id"
    self.subscription_id = data["subscription_id"]
  end
  if data.include? "token"
    self.token = data["token"]
  end
  if data.include? "token_id"
    self.token_id = data["token_id"]
  end
  if data.include? "details"
    self.details = data["details"]
  end
  if data.include? "url"
    self.url = data["url"]
  end
  if data.include? "name"
    self.name = data["name"]
  end
  if data.include? "amount"
    self.amount = data["amount"]
  end
  if data.include? "currency"
    self.currency = data["currency"]
  end
  if data.include? "merchant_initiator_type"
    self.merchant_initiator_type = data["merchant_initiator_type"]
  end
  if data.include? "statement_descriptor"
    self.statement_descriptor = data["statement_descriptor"]
  end
  if data.include? "statement_descriptor_phone"
    self.statement_descriptor_phone = data["statement_descriptor_phone"]
  end
  if data.include? "statement_descriptor_city"
    self.statement_descriptor_city = data["statement_descriptor_city"]
  end
  if data.include? "statement_descriptor_company"
    self.statement_descriptor_company = data["statement_descriptor_company"]
  end
  if data.include? "statement_descriptor_url"
    self.statement_descriptor_url = data["statement_descriptor_url"]
  end
  if data.include? "metadata"
    self. = data["metadata"]
  end
  if data.include? "gateway_data"
    self.gateway_data = data["gateway_data"]
  end
  if data.include? "return_url"
    self.return_url = data["return_url"]
  end
  if data.include? "cancel_url"
    self.cancel_url = data["cancel_url"]
  end
  if data.include? "webhook_url"
    self.webhook_url = data["webhook_url"]
  end
  if data.include? "require_backend_capture"
    self.require_backend_capture = data["require_backend_capture"]
  end
  if data.include? "sandbox"
    self.sandbox = data["sandbox"]
  end
  if data.include? "created_at"
    self.created_at = data["created_at"]
  end
  if data.include? "risk"
    self.risk = data["risk"]
  end
  if data.include? "shipping"
    self.shipping = data["shipping"]
  end
  if data.include? "device"
    self.device = data["device"]
  end
  if data.include? "external_fraud_tools"
    self.external_fraud_tools = data["external_fraud_tools"]
  end
  if data.include? "exemption_reason_3ds2"
    self.exemption_reason_3ds2 = data["exemption_reason_3ds2"]
  end
  if data.include? "sca_exemption_reason"
    self.sca_exemption_reason = data["sca_exemption_reason"]
  end
  if data.include? "challenge_indicator"
    self.challenge_indicator = data["challenge_indicator"]
  end
  
  self
end

#find(invoice_id, options = {}) ⇒ Object

Find an invoice by its ID. Params:

invoice_id

ID of the invoice

options

Hash of options



857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
# File 'lib/processout/invoice.rb', line 857

def find(invoice_id, options = {})
  self.prefill(options)

  request = Request.new(@client)
  path    = "/invoices/" + CGI.escape(invoice_id) + ""
  data    = {

  }

  response = Response.new(request.get(path, data, options))
  return_values = Array.new
  
  body = response.body
  body = body["invoice"]
  
  
  obj = Invoice.new(@client)
  return_values.push(obj.fill_with_data(body))
  

  
  return_values[0]
end

#initiate_three_d_s(source, options = {}) ⇒ Object

Initiate a 3-D Secure authentication Params:

source

Source used to initiate the 3-D Secure authentication. Can be a card, or a token representing a card

options

Hash of options



704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
# File 'lib/processout/invoice.rb', line 704

def initiate_three_d_s(source, options = {})
  self.prefill(options)

  request = Request.new(@client)
  path    = "/invoices/" + CGI.escape(@id) + "/three-d-s"
  data    = {
    "enable_three_d_s_2" => options.fetch(:enable_three_d_s_2, nil), 
    "source" => source
  }

  response = Response.new(request.post(path, data, options))
  return_values = Array.new
  
  body = response.body
  body = body["customer_action"]
  customer_action = CustomerAction.new(@client)
  return_values.push(customer_action.fill_with_data(body))

  
  return_values[0]
end

#new(data = {}) ⇒ Object

Create a new Invoice using the current client



371
372
373
# File 'lib/processout/invoice.rb', line 371

def new(data = {})
  Invoice.new(@client, data)
end

#prefill(data) ⇒ Object

Prefills the object with the data passed as parameters Params:

data

Hash of data



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
# File 'lib/processout/invoice.rb', line 543

def prefill(data)
  if data.nil?
    return self
  end
  self.id = data.fetch(:id, self.id)
  self.project = data.fetch(:project, self.project)
  self.project_id = data.fetch(:project_id, self.project_id)
  self.transaction = data.fetch(:transaction, self.transaction)
  self.transaction_id = data.fetch(:transaction_id, self.transaction_id)
  self.customer = data.fetch(:customer, self.customer)
  self.customer_id = data.fetch(:customer_id, self.customer_id)
  self.subscription = data.fetch(:subscription, self.subscription)
  self.subscription_id = data.fetch(:subscription_id, self.subscription_id)
  self.token = data.fetch(:token, self.token)
  self.token_id = data.fetch(:token_id, self.token_id)
  self.details = data.fetch(:details, self.details)
  self.url = data.fetch(:url, self.url)
  self.name = data.fetch(:name, self.name)
  self.amount = data.fetch(:amount, self.amount)
  self.currency = data.fetch(:currency, self.currency)
  self.merchant_initiator_type = data.fetch(:merchant_initiator_type, self.merchant_initiator_type)
  self.statement_descriptor = data.fetch(:statement_descriptor, self.statement_descriptor)
  self.statement_descriptor_phone = data.fetch(:statement_descriptor_phone, self.statement_descriptor_phone)
  self.statement_descriptor_city = data.fetch(:statement_descriptor_city, self.statement_descriptor_city)
  self.statement_descriptor_company = data.fetch(:statement_descriptor_company, self.statement_descriptor_company)
  self.statement_descriptor_url = data.fetch(:statement_descriptor_url, self.statement_descriptor_url)
  self. = data.fetch(:metadata, self.)
  self.gateway_data = data.fetch(:gateway_data, self.gateway_data)
  self.return_url = data.fetch(:return_url, self.return_url)
  self.cancel_url = data.fetch(:cancel_url, self.cancel_url)
  self.webhook_url = data.fetch(:webhook_url, self.webhook_url)
  self.require_backend_capture = data.fetch(:require_backend_capture, self.require_backend_capture)
  self.sandbox = data.fetch(:sandbox, self.sandbox)
  self.created_at = data.fetch(:created_at, self.created_at)
  self.risk = data.fetch(:risk, self.risk)
  self.shipping = data.fetch(:shipping, self.shipping)
  self.device = data.fetch(:device, self.device)
  self.external_fraud_tools = data.fetch(:external_fraud_tools, self.external_fraud_tools)
  self.exemption_reason_3ds2 = data.fetch(:exemption_reason_3ds2, self.exemption_reason_3ds2)
  self.sca_exemption_reason = data.fetch(:sca_exemption_reason, self.sca_exemption_reason)
  self.challenge_indicator = data.fetch(:challenge_indicator, self.challenge_indicator)
  
  self
end

#to_json(options) ⇒ Object

Overrides the JSON marshaller to only send the fields we want



376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
# File 'lib/processout/invoice.rb', line 376

def to_json(options)
  {
      "id": self.id,
      "project": self.project,
      "project_id": self.project_id,
      "transaction": self.transaction,
      "transaction_id": self.transaction_id,
      "customer": self.customer,
      "customer_id": self.customer_id,
      "subscription": self.subscription,
      "subscription_id": self.subscription_id,
      "token": self.token,
      "token_id": self.token_id,
      "details": self.details,
      "url": self.url,
      "name": self.name,
      "amount": self.amount,
      "currency": self.currency,
      "merchant_initiator_type": self.merchant_initiator_type,
      "statement_descriptor": self.statement_descriptor,
      "statement_descriptor_phone": self.statement_descriptor_phone,
      "statement_descriptor_city": self.statement_descriptor_city,
      "statement_descriptor_company": self.statement_descriptor_company,
      "statement_descriptor_url": self.statement_descriptor_url,
      "metadata": self.,
      "gateway_data": self.gateway_data,
      "return_url": self.return_url,
      "cancel_url": self.cancel_url,
      "webhook_url": self.webhook_url,
      "require_backend_capture": self.require_backend_capture,
      "sandbox": self.sandbox,
      "created_at": self.created_at,
      "risk": self.risk,
      "shipping": self.shipping,
      "device": self.device,
      "external_fraud_tools": self.external_fraud_tools,
      "exemption_reason_3ds2": self.exemption_reason_3ds2,
      "sca_exemption_reason": self.sca_exemption_reason,
      "challenge_indicator": self.challenge_indicator,
  }.to_json
end

#void(options = {}) ⇒ Object

Void the invoice Params:

options

Hash of options



753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
# File 'lib/processout/invoice.rb', line 753

def void(options = {})
  self.prefill(options)

  request = Request.new(@client)
  path    = "/invoices/" + CGI.escape(@id) + "/void"
  data    = {

  }

  response = Response.new(request.post(path, data, options))
  return_values = Array.new
  
  body = response.body
  body = body["transaction"]
  transaction = Transaction.new(@client)
  return_values.push(transaction.fill_with_data(body))

  
  return_values[0]
end