Class: ProcessOut::Invoice
- Inherits:
-
Object
- Object
- ProcessOut::Invoice
- Defined in:
- lib/processout/invoice.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Returns the value of attribute amount.
-
#cancel_url ⇒ Object
Returns the value of attribute cancel_url.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#customer ⇒ Object
Returns the value of attribute customer.
-
#id ⇒ Object
Returns the value of attribute id.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#name ⇒ Object
Returns the value of attribute name.
-
#project ⇒ Object
Returns the value of attribute project.
-
#request_email ⇒ Object
Returns the value of attribute request_email.
-
#request_shipping ⇒ Object
Returns the value of attribute request_shipping.
-
#return_url ⇒ Object
Returns the value of attribute return_url.
-
#sandbox ⇒ Object
Returns the value of attribute sandbox.
-
#subscription ⇒ Object
Returns the value of attribute subscription.
-
#transaction ⇒ Object
Returns the value of attribute transaction.
-
#url ⇒ Object
Returns the value of attribute url.
Instance Method Summary collapse
-
#all(options = {}) ⇒ Object
Get all the invoices.
-
#assign_customer(customer_id, options = {}) ⇒ Object
Assign a customer to the invoice.
-
#authorize(source, options = {}) ⇒ Object
Authorize the invoice using the given source (customer or token) Params:
source:: Source used to authorization the payment. -
#capture(source, options = {}) ⇒ Object
Capture the invoice using the given source (customer or token) Params:
source:: Source used to authorization the payment. -
#create(options = {}) ⇒ Object
Create a new invoice.
-
#create_for_customer(customer_id, options = {}) ⇒ Object
Create a new invoice for the given customer ID.
-
#fetch_customer(options = {}) ⇒ Object
Get the customer linked to the invoice.
-
#fetch_transaction(options = {}) ⇒ Object
Get the transaction of the invoice.
-
#fill_with_data(data) ⇒ Object
Fills the object with data coming from the API Params:
data::Hashof data coming from the API. -
#find(invoice_id, options = {}) ⇒ Object
Find an invoice by its ID.
-
#initialize(client, data = {}) ⇒ Invoice
constructor
Initializes the Invoice object Params:
client::ProcessOutclient instancedata:: data that can be used to fill the object. -
#new(data = {}) ⇒ Object
Create a new Invoice using the current client.
-
#prefill(data) ⇒ Object
Prefills the object with the data passed as Parameters Params:
data::Hashof data. -
#void(options = {}) ⇒ Object
Void the invoice Params:
options::Hashof options.
Constructor Details
#initialize(client, data = {}) ⇒ Invoice
Initializes the Invoice object Params:
clientProcessOutclient instancedatadata that can be used to fill the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/processout/invoice.rb', line 125 def initialize(client, data = {}) @client = client self.id = data.fetch(:id, nil) self.project = data.fetch(:project, nil) self.transaction = data.fetch(:transaction, nil) self.customer = data.fetch(:customer, nil) self.subscription = data.fetch(:subscription, nil) self.url = data.fetch(:url, nil) self.name = data.fetch(:name, nil) self.amount = data.fetch(:amount, nil) self.currency = data.fetch(:currency, nil) self. = data.fetch(:metadata, nil) self.request_email = data.fetch(:request_email, nil) self.request_shipping = data.fetch(:request_shipping, nil) self.return_url = data.fetch(:return_url, nil) self.cancel_url = data.fetch(:cancel_url, nil) self.sandbox = data.fetch(:sandbox, nil) self.created_at = data.fetch(:created_at, nil) end |
Instance Attribute Details
#amount ⇒ Object
Returns the value of attribute amount.
17 18 19 |
# File 'lib/processout/invoice.rb', line 17 def amount @amount end |
#cancel_url ⇒ Object
Returns the value of attribute cancel_url.
23 24 25 |
# File 'lib/processout/invoice.rb', line 23 def cancel_url @cancel_url end |
#created_at ⇒ Object
Returns the value of attribute created_at.
25 26 27 |
# File 'lib/processout/invoice.rb', line 25 def created_at @created_at end |
#currency ⇒ Object
Returns the value of attribute currency.
18 19 20 |
# File 'lib/processout/invoice.rb', line 18 def currency @currency end |
#customer ⇒ Object
Returns the value of attribute customer.
13 14 15 |
# File 'lib/processout/invoice.rb', line 13 def customer @customer end |
#id ⇒ Object
Returns the value of attribute id.
10 11 12 |
# File 'lib/processout/invoice.rb', line 10 def id @id end |
#metadata ⇒ Object
Returns the value of attribute metadata.
19 20 21 |
# File 'lib/processout/invoice.rb', line 19 def end |
#name ⇒ Object
Returns the value of attribute name.
16 17 18 |
# File 'lib/processout/invoice.rb', line 16 def name @name end |
#project ⇒ Object
Returns the value of attribute project.
11 12 13 |
# File 'lib/processout/invoice.rb', line 11 def project @project end |
#request_email ⇒ Object
Returns the value of attribute request_email.
20 21 22 |
# File 'lib/processout/invoice.rb', line 20 def request_email @request_email end |
#request_shipping ⇒ Object
Returns the value of attribute request_shipping.
21 22 23 |
# File 'lib/processout/invoice.rb', line 21 def request_shipping @request_shipping end |
#return_url ⇒ Object
Returns the value of attribute return_url.
22 23 24 |
# File 'lib/processout/invoice.rb', line 22 def return_url @return_url end |
#sandbox ⇒ Object
Returns the value of attribute sandbox.
24 25 26 |
# File 'lib/processout/invoice.rb', line 24 def sandbox @sandbox end |
#subscription ⇒ Object
Returns the value of attribute subscription.
14 15 16 |
# File 'lib/processout/invoice.rb', line 14 def subscription @subscription end |
#transaction ⇒ Object
Returns the value of attribute transaction.
12 13 14 |
# File 'lib/processout/invoice.rb', line 12 def transaction @transaction end |
#url ⇒ Object
Returns the value of attribute url.
15 16 17 |
# File 'lib/processout/invoice.rb', line 15 def url @url end |
Instance Method Details
#all(options = {}) ⇒ Object
Get all the invoices. Params:
optionsHashof options
388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/processout/invoice.rb', line 388 def all( = {}) self.prefill() request = Request.new(@client) path = "/invoices" data = { } response = Response.new(request.get(path, data, )) return_values = Array.new a = Array.new body = response.body for v in body['invoices'] tmp = Invoice.new(@client) tmp.fill_with_data(v) a.push(tmp) end return_values.push(a) return_values[0] end |
#assign_customer(customer_id, options = {}) ⇒ Object
Assign a customer to the invoice. Params:
customer_idID of the customer to be linked to the invoice
optionsHashof options
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/processout/invoice.rb', line 316 def assign_customer(customer_id, = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(@id) + "/customers" data = { "customer_id" => customer_id } response = Response.new(request.post(path, data, )) return_values = Array.new body = response.body body = body["customer"] customer = Customer.new(@client) return_values.push(customer.fill_with_data(body)) return_values[0] end |
#authorize(source, options = {}) ⇒ Object
Authorize the invoice using the given source (customer or token) Params:
sourceSource used to authorization the payment. Can be a card, a token or a gateway request
optionsHashof options
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/processout/invoice.rb', line 242 def (source, = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(@id) + "/authorize" data = { "source" => source } response = Response.new(request.post(path, data, )) return_values = Array.new body = response.body body = body["transaction"] transaction = Transaction.new(@client) return_values.push(transaction.fill_with_data(body)) return_values[0] end |
#capture(source, options = {}) ⇒ Object
Capture the invoice using the given source (customer or token) Params:
sourceSource used to authorization the payment. Can be a card, a token or a gateway request
optionsHashof options
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/processout/invoice.rb', line 267 def capture(source, = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(@id) + "/capture" data = { "source" => source } response = Response.new(request.post(path, data, )) return_values = Array.new body = response.body body = body["transaction"] transaction = Transaction.new(@client) return_values.push(transaction.fill_with_data(body)) return_values[0] end |
#create(options = {}) ⇒ Object
Create a new invoice. Params:
optionsHashof options
418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 |
# File 'lib/processout/invoice.rb', line 418 def create( = {}) self.prefill() request = Request.new(@client) path = "/invoices" data = { "name" => @name, "amount" => @amount, "currency" => @currency, "metadata" => , "request_email" => @request_email, "request_shipping" => @request_shipping, "return_url" => @return_url, "cancel_url" => @cancel_url } response = Response.new(request.post(path, data, )) return_values = Array.new body = response.body body = body["invoice"] return_values.push(self.fill_with_data(body)) return_values[0] end |
#create_for_customer(customer_id, options = {}) ⇒ Object
Create a new invoice for the given customer ID. Params:
customer_idID of the customer
optionsHashof options
452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/processout/invoice.rb', line 452 def create_for_customer(customer_id, = {}) self.prefill() request = Request.new(@client) path = "/invoices" data = { "name" => @name, "amount" => @amount, "currency" => @currency, "metadata" => , "request_email" => @request_email, "request_shipping" => @request_shipping, "return_url" => @return_url, "cancel_url" => @cancel_url, "customer_id" => customer_id } response = Response.new(request.post(path, data, )) return_values = Array.new body = response.body body = body["invoice"] return_values.push(self.fill_with_data(body)) return_values[0] end |
#fetch_customer(options = {}) ⇒ Object
Get the customer linked to the invoice. Params:
optionsHashof options
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/processout/invoice.rb', line 291 def fetch_customer( = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(@id) + "/customers" data = { } response = Response.new(request.get(path, data, )) return_values = Array.new body = response.body body = body["customer"] customer = Customer.new(@client) return_values.push(customer.fill_with_data(body)) return_values[0] end |
#fetch_transaction(options = {}) ⇒ Object
Get the transaction of the invoice. Params:
optionsHashof options
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/processout/invoice.rb', line 340 def fetch_transaction( = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(@id) + "/transactions" data = { } response = Response.new(request.get(path, data, )) return_values = Array.new body = response.body body = body["transaction"] transaction = Transaction.new(@client) return_values.push(transaction.fill_with_data(body)) return_values[0] end |
#fill_with_data(data) ⇒ Object
Fills the object with data coming from the API Params:
dataHashof data coming from the API
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/processout/invoice.rb', line 155 def fill_with_data(data) if data.nil? return self end if data.include? "id" self.id = data["id"] end if data.include? "project" self.project = data["project"] end if data.include? "transaction" self.transaction = data["transaction"] end if data.include? "customer" self.customer = data["customer"] end if data.include? "subscription" self.subscription = data["subscription"] end if data.include? "url" self.url = data["url"] end if data.include? "name" self.name = data["name"] end if data.include? "amount" self.amount = data["amount"] end if data.include? "currency" self.currency = data["currency"] end if data.include? "metadata" self. = data["metadata"] end if data.include? "request_email" self.request_email = data["request_email"] end if data.include? "request_shipping" self.request_shipping = data["request_shipping"] end if data.include? "return_url" self.return_url = data["return_url"] end if data.include? "cancel_url" self.cancel_url = data["cancel_url"] end if data.include? "sandbox" self.sandbox = data["sandbox"] end if data.include? "created_at" self.created_at = data["created_at"] end self end |
#find(invoice_id, options = {}) ⇒ Object
Find an invoice by its ID. Params:
invoice_idID of the invoice
optionsHashof options
487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/processout/invoice.rb', line 487 def find(invoice_id, = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(invoice_id) + "" data = { } response = Response.new(request.get(path, data, )) return_values = Array.new body = response.body body = body["invoice"] obj = Invoice.new(@client) return_values.push(obj.fill_with_data(body)) return_values[0] end |
#new(data = {}) ⇒ Object
Create a new Invoice using the current client
148 149 150 |
# File 'lib/processout/invoice.rb', line 148 def new(data = {}) Invoice.new(@client, data) end |
#prefill(data) ⇒ Object
Prefills the object with the data passed as Parameters Params:
dataHashof data
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/processout/invoice.rb', line 214 def prefill(data) if data.nil? return self end self.id = data.fetch(:id, self.id) self.project = data.fetch(:project, self.project) self.transaction = data.fetch(:transaction, self.transaction) self.customer = data.fetch(:customer, self.customer) self.subscription = data.fetch(:subscription, self.subscription) self.url = data.fetch(:url, self.url) self.name = data.fetch(:name, self.name) self.amount = data.fetch(:amount, self.amount) self.currency = data.fetch(:currency, self.currency) self. = data.fetch(:metadata, self.) self.request_email = data.fetch(:request_email, self.request_email) self.request_shipping = data.fetch(:request_shipping, self.request_shipping) self.return_url = data.fetch(:return_url, self.return_url) self.cancel_url = data.fetch(:cancel_url, self.cancel_url) self.sandbox = data.fetch(:sandbox, self.sandbox) self.created_at = data.fetch(:created_at, self.created_at) self end |
#void(options = {}) ⇒ Object
Void the invoice Params:
optionsHashof options
364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/processout/invoice.rb', line 364 def void( = {}) self.prefill() request = Request.new(@client) path = "/invoices/" + CGI.escape(@id) + "/void" data = { } response = Response.new(request.post(path, data, )) return_values = Array.new body = response.body body = body["transaction"] transaction = Transaction.new(@client) return_values.push(transaction.fill_with_data(body)) return_values[0] end |